==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/PMWORKPACKAGEEMPLOYEEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PMWORKPACKAGEEMPLOYEEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMWORKPACKAGEEMPLOYEEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMWORKPACKAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMWORKPACKAGEEMPLOYEEID_Type", propOrder = {
    "pmworkpackageid",
    "employeeid"
})
public class PMWORKPACKAGEEMPLOYEEID_Type {

    @XmlElement(name = "PMWORKPACKAGEID", required = true)
    protected PMWORKPACKAGEID_Type pmworkpackageid;
    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;

    /**
     * Obtient la valeur de la propriété pmworkpackageid.
     * 
     * @return
     *     possible object is
     *     {@link PMWORKPACKAGEID_Type }
     *     
     */
    public PMWORKPACKAGEID_Type getPMWORKPACKAGEID() {
        return pmworkpackageid;
    }

    /**
     * Définit la valeur de la propriété pmworkpackageid.
     * 
     * @param value
     *     allowed object is
     *     {@link PMWORKPACKAGEID_Type }
     *     
     */
    public void setPMWORKPACKAGEID(PMWORKPACKAGEID_Type value) {
        this.pmworkpackageid = value;
    }

    /**
     * Obtient la valeur de la propriété employeeid.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Définit la valeur de la propriété employeeid.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/PMWORKPACKAGEEMPLOYEEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PMWORKPACKAGEEMPLOYEEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMWORKPACKAGEEMPLOYEEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMWORKPACKAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMWORKPACKAGEEMPLOYEEID_Type", propOrder = {
    "pmworkpackageid",
    "employeeid"
})
public class PMWORKPACKAGEEMPLOYEEID_Type {

    @XmlElement(name = "PMWORKPACKAGEID", required = true)
    protected PMWORKPACKAGEID_Type pmworkpackageid;
    @XmlElement(name = "EMPLOYEEID", required = true)
    protected Employee_Type employeeid;

    /**
     * Gets the value of the pmworkpackageid property.
     * 
     * @return
     *     possible object is
     *     {@link PMWORKPACKAGEID_Type }
     *     
     */
    public PMWORKPACKAGEID_Type getPMWORKPACKAGEID() {
        return pmworkpackageid;
    }

    /**
     * Sets the value of the pmworkpackageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PMWORKPACKAGEID_Type }
     *     
     */
    public void setPMWORKPACKAGEID(PMWORKPACKAGEID_Type value) {
        this.pmworkpackageid = value;
    }

    /**
     * Gets the value of the employeeid property.
     * 
     * @return
     *     possible object is
     *     {@link Employee_Type }
     *     
     */
    public Employee_Type getEMPLOYEEID() {
        return employeeid;
    }

    /**
     * Sets the value of the employeeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Employee_Type }
     *     
     */
    public void setEMPLOYEEID(Employee_Type value) {
        this.employeeid = value;
    }

}
